| assess_coa | R Documentation |
Assess course objective achievement
assess_coa(data, session_weights, objective_weights1, ...)
data |
A wide-format data.frame that only contains student's grades of each session.
|
session_weights |
A vector that Weights sessions for the final grade.
The length of |
objective_weights1 |
A vector that Weights course objectives for session 1.
The length of objective_weights1 is the number of course objectives.
The range of each weight should be 0-1. The sum of |
... |
objective_weights2, objective_weights3, ...
Other vectors that Weight course objectives for session1, session2, ...
The number of objective_weights* arguments should be equal to the length of |
A data.frame containing grades of each session, final grades, and achievements of each objective. This data.frame also has an attribute named "weights" that contains a list of session_weights, objective_weights_matrix, and weighted_objective_weights_matrix
data <- data.frame(
session1 = 60 + sample.int(40, 100, 1),
session2 = 60 + sample.int(40, 100, 1),
session3 = 60 + sample.int(40, 100, 1)
)
session_weights <- c(0.2, 0.3, 0.5)
objective_weights1 <- c(0.1, 0.4, 0.5)
objective_weights2 <- c(0.2, 0.2, 0.6)
objective_weights2 <- c(0.3, 0, 0.7)
coa <- assess_coa(
data,
session_weights,
objective_weights1,
objective_weights2,
objective_weights2
)
head(coa)
attr(coa, "weights")
colMeans(coa[row.names(attr(coa, "weights")[[2]])])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.